var APIBase = require("../../api.base");
var system = require("../../../system");
var settings = require("../../../../config/settings");
class ActionAPI extends APIBase {
    constructor() {
        super();
        this.merchantSve = system.getObject("service.merchant.merchantSve");
        this.orderSve = system.getObject("service.order.orderSve");
        this.businessmenSve = system.getObject("service.order.businessmenSve");


        // wk
        this.merchantrechargeSve = system.getObject("service.merchant.merchantrechargeSve");
        this.invoiceSve = system.getObject("service.invoice.invoiceSve");
        // wk
    }
    /**
     * 接口跳转
     * action_process  执行的流程
     * action_type     执行的类型
     * action_body     执行的参数
     */
    async springboard(pobj, qobj, req) {
        if (!pobj.action_process) {
            return system.getResult(null, "action_process参数不能为空");
        }
        if (!pobj.action_type) {
            return system.getResult(null, "action_type参数不能为空");
        }
        var result = null;
        switch (pobj.action_process) {
            case "sjb"://司机宝
                result = await this.sjbOpActionProcess(pobj.action_process, pobj.action_type, pobj.action_body);
                break;
            default:
                result = system.getResult(null, "action_process参数错误");
                break;
        }
        return result;
    }

    async sjbOpActionProcess(action_process, action_type, action_body) {
        var opResult = null;
        switch (action_type) {
            // sy
            case "queryMerchant"://查询商户
                opResult = await this.merchantSve.queryMerchant(action_body);
                break;
            case "addOrder"://添加订单
                opResult = await this.orderSve.addOrder(action_body);
                break;
            case "putOrder"://修改订单
                opResult = await this.orderSve.putOrder(action_body);
                break;
            case "queryOrder"://订单查询
                opResult = await this.orderSve.queryOrder(action_body);
                break;
            case "putContract"://个体工商户合同接收接口
                opResult = await this.businessmenSve.putContract(action_body);
                break;
            case "queryBusinessmen"://个体工商户信息查询接口
                opResult = await this.businessmenSve.queryBusinessmen(action_body);
                break;

            // sy


            // wk
            case "rechargeApplication":// 商户充值申请
                opResult = await this.merchantrechargeSve.apiSave(action_body);
                break;
            case "calcInvoice": // 发票试算接口
                opResult = await this.invoiceSve.apiCalcInvoice(action_body);
                break;
            case "saveInvoice": // 发票提交接口
                opResult = await this.invoiceSve.apiSaveInvoice(action_body);
                break;
            case  "cancelInvoice": // 发票提交接口
                opResult = await this.invoiceSve.apiCancelInvoice(action_body);
                break;



            // 以下接口为推送测试
            case "testRechargeAudit":// 发票信息查询接口
                opResult = await this.merchantrechargeSve.apiAudit(action_body);
                break;
            case "testInvoiceAudit": // 发票审核
                opResult = await this.invoiceSve.testInvoiceAudit(action_body);
                break;
            case "testKaipiao": // 发票状态已开具
                opResult = await this.invoiceSve.testKaipiao(action_body);
                break;
            case "testToemail": // 发票已邮寄
                opResult = await this.invoiceSve.testToemail(action_body);
                break;
            case "testTaxCertificate": // 发票已邮寄
                opResult = await this.invoiceSve.testToemail(action_body);
                break;
            // wk
            default:
                opResult = system.getResult(null, "action_type参数错误");
                break;
        }
        return opResult;
    }
    exam() {
        return `<pre>
1.queryMerchant：查询商户   
    请求参数：
        {
                "action_process": "sjb",
                "action_type": "queryMerchant",
                "action_body": {
                    "sign":"CBCE83769118A4D8906F097ECA558ACF",
                    "times_tamp": 1568713248
                }
        }
    请求参数说明：
        sign      ：签名
        times_tamp：时间戳
    返回值：
        {
            "status": 0,
            "msg": "success",
            "data": {
                "contactEmail": "qjyang@gongsibao.com",
                "taxNo": "xxxx2222xxxx",
                "invoiceAddr": "北京市朝阳区来广营",
                "invoiceMobile": "18810277728",
                "accountName": "公司宝",
                "contactName": "杨庆菊",
                "accountPublic": "22222222",
                "mailAddr": "qjyang@gongsibao.com",
                "taxType": 0,
                "mailTo": "杨庆菊",
                "mailMobile": "18810277728",
                "status": 0,
                "name": "司机宝",
                "contactMobile": "18810277728"
            },
            "requestid": "8cbd498f9d1441b1812ecaa2653933f4"
        }
    返回值说明：
        name         ：商户名称                                          
        taxType      ：纳税人类型 0一般纳税人 1小规模纳税人  
        contactName  ：联系人姓名                                       
        contactMobile：联系人手机                                       
        contactEmail ：联系人邮箱                                       
        taxNo        ：纳税人识别号                                    
        invoiceAddr  ：开票地址                                          
        invoiceMobile：开票电话                                          
        accountName  ：开户名称                                          
        accountPublic：对公账户                                          
        mailAddr     ：邮寄地址                                          
        mailTo       ：收件人                                             
        mailMobile   ：收件电话                                             
        status       ：订单状态 0待审核 1待签约 2签约完成    

2.addOrder/putOrder：添加订单/修改订单
    请求参数：
        {
            "action_process": "sjb",
            "action_type": "addOrder",
            "action_body": {
                "sign": "CBCE83769118A4D8906F097ECA558ACF",
                "times_tamp": 1568713248,
                "channelOrderNo": "test0002",
                "legalName": "测试法人修改",
                "legalMobile": "15010929368",
                "legalImg": "http://sss1.jpg",
                "idcard": 341221198808328543,
                "idcardFront": "http://sss2.jpg",
                "idcardBack": "http://sss3.jpg",
                "bankNo": "33333990209874819",
                "bank": "北京市地球村",
                "names": "名称1,名称2,名称3",
                "businessScope": "科技服务行业",
                "capital": "1000万"
            }
        }
    请求参数说明：
        sign          ：签名
        times_tamp    ：时间戳
        channelOrderNo：渠道单号                                                                                
        legalName     ：法人姓名                                                                                
        legalMobile   ：法人电话                                                                                
        legalImg      ：法人证件照                                                                             
        idcard        ：法人身份证                                                                             
        idcardFront   ：身份证正面照片                                                                       
        idcardBack    ：身份证反面照片                                                                       
        bankNo        ：银行卡号                                                                                
        bank          ：开户行                                                                                   
        names         ：个体户名称，多个格式为：name1,name2,name3                                                                             
        businessScope ：经营范围                                                                                
        capital       ：注册资本            
    返回值：
        添加返回值：
            {
                "status": 0,
                "msg": "success",
                "data": {
                    "id": 8,
                    "orderNo": "SJB201909191148sJXGu",
                    "status": "00"
                },
                "requestid": "9952e339512740ebb6e5df72a4c09895"
            }
        修改返回值：
            {
                "status": 0,
                "msg": "success",
                "data": null,
                "requestid": "e8f31dacc07c4764b8fd4f9955622385"
            }                       
    返回值说明：
            orderNo     ：订单号                                          
            status      ：订单状态 00待处理 05执照办理中 10已出执照 15刻章办理中 20已刻章 25银行开户中 30银行已开户 35税务报到中 40已税务报到  50已邮寄     

3.queryOrder：订单查询   
    请求参数：
        {
            "action_process": "sjb",
            "action_type": "queryOrder",
            "action_body": {
                "sign": "CBCE83769118A4D8906F097ECA558ACF",
                "times_tamp": 1568713248,
                "channelOrderNo": "test0001"
            }
        }
    请求参数说明：
        sign           ：签名
        times_tamp     ：时间戳
        channelOrderNo ：渠道订单号
    返回值：
        {
            "status": 0,
            "msg": "success",
            "data": {
                "orderNo": "SJB2019091816016FXaj",
                "channelOrderNo": "test0001",
                "legalName": "测试法人修改",
                "legalMobile": "15010929368",
                "legalImg": "http://sss1.jpg",
                "idcard": "341221198808328500",
                "idcardFront": "http://sss2.jpg",
                "idcardBack": "http://sss3.jpg",
                "bankNo": "33333990209874819",
                "bank": "北京市地球村",
                "names": "名称1,名称2,名称3",
                "businessScope": "科技服务行业",
                "capital": "1000万",
                "status": "10",
                "opNotes": null
            },
            "requestid": "d108d7fa93984886a3a659114e188a75"
        }
    返回值说明：
        orderNo       ：订单号                                                                                   
        channelOrderNo：渠道单号                                                                                
        legalName     ：法人姓名                                                                                
        legalMobile   ：法人电话                                                                                
        legalImg      ：法人证件照                                                                             
        idcard        ：法人身份证                                                                             
        idcardFront   ：身份证正面照片                                                                       
        idcardBack    ：身份证反面照片                                                                       
        bankNo        ：银行卡号                                                                                
        bank          ：开户行                                                                                   
        names         ：个体户名称                                                                             
        businessScope ：经营范围                                                                                
        capital       ：注册资本                                                                                
        status        ：订单状态 00待处理 05执照办理中 10已出执照 15刻章办理中 20已刻章 25银行开户中 30银行已开户 35税务报到中 40已税务报到 50已邮寄
        opNotes       ：操作备注   

4.putContract：个体工商户合同接收接口   
    请求参数：
        {
            "action_process": "sjb",
            "action_type": "putContract",
            "action_body": {
                "sign": "CBCE83769118A4D8906F097ECA558ACF",
                "times_tamp": 1568713248,
                "channelOrderNo": "test0001",
                "contract": "http://ttt.jpg",
                "contractStartData": "2019-01-10",
                "contractEndData": "2020-01-10"
            }
        }
    请求参数说明：
        sign              ：签名
        times_tamp        ：时间戳
        channelOrderNo    ：渠道订单号
        contract          ：合同地址
        contractStartData ：合同开始时间
        contractEndData   ：合同结束时间
    返回值：
        {
            "status": 0,
            "msg": "success",
            "data": null,
            "requestid": "b14a73f9d6d84fc7be1e62feaf8316a0"
        }
5.queryMerchantAccount: 商户账户查询
    请求参数：
        {
            "action_process": "sjb",
            "action_type": "queryMerchantAccount",
            "action_body": {
                "sign": "CBCE83769118A4D8906F097ECA558ACF",
                "times_tamp": 1568713248
            }
        }
    返回值：
        {
            "status": 0,
            "msg": "success",
            "data": {
                "merchant_id": "SJB2019091816016FXaj",  // 商户ID
                "frozen_amt": 11111111,     // 冻结余额
                "available_amt": 2222222    // 可用余额
            },
            "requestid": "305bcbe9b7f444e38c6155033e6cb66c"
        }
6.queryMerchantTrade: 商户交易流水查询
    请求参数：
        {
            "action_process": "sjb",
            "action_type": "queryMerchantTrade",
            "action_body": {
                "sign": "CBCE83769118A4D8906F097ECA558ACF",
                "times_tamp": 1568713248,
                "outTradeNo": "",      // 充值流水号（选填）
                "applyNo": "",         // 发票申请号（选填）
                "currentPage": 1,      // 页码 从1开始, 默认为1
                "pageSize": 10         // 每页条数 默认10
            }
        }
    返回值：
        {
            "status": 0,
            "msg": "success",
            "data": [
                merchant_id: "SJB2019091816016FXaj",  // 商户ID
                outTradeNo: "",                 // 充值流水号
                applyNo: "",                    // 发票申请号
                amt: "",                        // 交易金额
                type: "",                       // 收支类型 1充值 2支出
                businessType: "",               // 业务类型 00服务费扣款 10个税扣款 20增值费扣款 30附加费扣款 90充值入账
            },
            "requestid": "305bcbe9b7f444e38c6155033e6cb66c"
        }

7.queryBusinessmen：个体工商户信息查询接口   
    请求参数：
        {
            "action_process": "sjb",
            "action_type": "queryBusinessmen",
            "action_body": {
                "sign": "CBCE83769118A4D8906F097ECA558ACF",
                "times_tamp": 1568713248,
                "channelOrderNo": "test0001"
            }
        }
    请求参数说明：
        sign           ：签名
        times_tamp     ：时间戳
        channelOrderNo ：渠道订单号
    返回值：
        {
            "status": 0,
            "msg": "success",
            "data": {
                "orderNo": "SJB2019091816016FXaj",
                "channelOrderNo": "test0001",
                "status": "60",
                "legalName": "测试法人修改",
                "legalMobile": "15010929368",
                "name": "",
                "creditCode": "",
                "businessPlace": "",
                "businessScope": "",
                "regDate": null,
                "businessImg": "",
                "gongzhang": "",
                "caiwuzhang": "",
                "fapiaozhang": "",
                "hetongzhang": "",
                "farenzhang": "",
                "isBank": false,
                "bankName": "",
                "bankNo": "",
                "bank": "",
                "bankImg": "",
                "caImg": "",
                "taxRegDay": null,
                "taxOrg": "",
                "courierNo": "",
                "courierImg": "",
                "addedValueRate": 0,
                "supertaxRate": 0,
                "commonTaxLadder": "",
                "commonOtherLadder": "",
                "specialTaxLadder": "",
                "specialOtherLadder": "",
                "contractStartData": "2019-01-10T00:00:00.000Z",
                "contractEndData": "2020-01-10T00:00:00.000Z",
                "contract": "http://ttt.jpg",
                "opNotes": null
            },
            "requestid": "305bcbe9b7f444e38c6155033e6cb66c"
        }
    返回值说明：
        orderNo           ：订单号                                                                                                                                                           
        channelOrderNo    ：渠道订单号                                                                                                                                                     
        status            ：状态 00待处理 05执照办理中 10已出执照 15刻章办理中 20已刻章 25银行开户中 30银行已开户 35税务报到中 40已税务报到 50已邮寄 60 合同待审核 70 合同审核不通过 80 合同审核通过 90已签约  
        legalName         ：法人姓名                                                                                                                                                        
        legalMobile       ：法人电话                                                                                                                                                        
        name              ：个体工商户名称                                                                                                                                               
        creditCode        ：统一社会信用代码                                                                                                                                            
        businessPlace     ：经营场所                                                                                                                                                        
        businessScope     ：经营范围                                                                                                                                                        
        regDate           ：注册日期                                                                                                                                                        
        businessImg       ：执照照片                                                                                                                                                        
        gongzhang         ：公章                                                                                                                                                              
        caiwuzhang        ：财务章                                                                                                                                                           
        fapiaozhang       ：发票章                                                                                                                                                           
        hetongzhang       ：合同章                                                                                                                                                           
        farenzhang        ：法人章                                                                                                                                                           
        isBank            ：是否开户                                                                                                                                                        
        bankName          ：账户名称                                                                                                                                                        
        bankNo            ：账户号                                                                                                                                                           
        bank              ：开户行                                                                                                                                                           
        bankImg           ：账户信息                                                                                                                                                        
        caImg             ：CA照片                                                                                                                                                            
        taxRegDay         ：税务登记日                                                                                                                                                     
        taxOrg            ：税务机构名称                                                                                                                                                  
        courierNo         ：快递单号                                                                                                                                                        
        courierImg        ：快递交接单图片                                                                                                                                               
        addedValueRate    ：增值税率                                                                                                                                                        
        supertaxRate      ：附加税率                                                                                                                                                        
        commonTaxLadder   ：普票个税阶梯                                                                                                                                                  
        commonOtherLadder ：普票增值税、附加税阶梯                                                                                                                                   
        specialTaxLadder  ：专票个税阶梯                                                                                                                                                  
        specialOtherLadder：专票增值税、附加税阶梯                                                                                                                                   
        contract          ：个体户合同                                                                                                                                                     
        contractStartData ：合同开始时间                                                                                                                                                  
        contractEndData   ：合同结束时间                                                                                                                                                                    
        opNotes           ：操作备注   
        
8.rechargeApplication：商户充值申请接口   
    请求参数：
        {
            "action_process": "sjb",
            "action_type": "rechargeApplication",
            "action_body": {
                "amt": 100000,
                "outTradeNo":"1",
                "times_tamp": 1568713248,
                "sign": "D4393F17C96CDA582C1EE5FF0053671E",
                "voucher":"https://www.xxx.com/1.png"
            }
        }
    请求参数说明：
        sign           ：签名
        times_tamp     ：时间戳
        amt            ：充值金额（分为单位）
        outTradeNo     ：充值流水号（商户下不能重复）
        voucher        ：充值凭证图片地址
    返回值：
        {
            "status": 0,
            "msg": "success",
            "requestid": "305bcbe9b7f444e38c6155033e6cb66c"
        }


9.calcInvoice：发票试算接口   
    请求参数：
        {
            "action_process": "sjb",
            "action_type": "calcInvoice",
            "action_body": {
                "invoiceList": [
                    {
                        "businessmenCreditCode":"1111",
                        "invoiceTime": "2019-09-19",
                        "invoiceAmt":440000000,
                        "type": 1
                    }
                ],
                "times_tamp": 1568713248,
                "sign": "D4393F17C96CDA582C1EE5FF0053671E"
            }
        }
    请求参数说明：
        sign                      ：签名
        times_tamp                ：时间戳
        invoiceList               ：发票试算列表，最多不超过10个，不参与签名
        businessmenCreditCode     ：个体工商户统一社会信用代码
        invoiceTime               ：开票时间
        invoiceAmt                ：开票金额（分）
        type                      ：开票类型 0普票 1专票
    返回值：
        {
            "status": 0,
            "msg": "success",
            "data": {
                "1": {
                    "code": 1,
                    "msg": "success",
                    "incomeTax": "20042494",
                    "addedValueTax": "28042996",
                    "specialTax": "2720171",
                    "serviceTax": "9372000",
                    "warning": "年度总开票金额已达到4400000",
                    "monthAmt": 440000
                }
            },
            "requestid": "363e0391a43c4dedb5656623d1bcd540"
        }
    返回值说明：
        data                        : 发票处理结果，Map格式，key为个体工商户统一社会信用代码
            "1"                     : 统一社会信用代码
                "code"              : 该个体工商户试算状态 1成功 -1失败
                    "msg"           : 试算结果提示，错误时返回错误信息    
                    "incomeTax"     : 试算个税结果（分）
                    "addedValueTax" : 试算增值税结果（分）
                    "specialTax"    : 试算附加费结果（分）
                    "serviceTax"    : 试算服务费结果（分）
                    "warning"       : 警告信息，该字段不为空时，在前端显示,
                    "monthAmt"      : 该个体工商户在开票时间的月分中，已经申请开票的总金额

10.saveInvoice：申请开票接口   
    请求参数：
    {
        "action_process": "sjb",
        "action_type": "saveInvoice",
        "action_body": {
            "invoiceList": [
                {
                    "businessmenCreditCode":"1111",
                    "invoiceTime": "2019-09-19",
                    "applyNo": "100001",
                    "invoiceAmt":330000,
                    "settleImg": "https://bpohhr.gongsibao.com",
                    "type": 1
                },
                {
                    "businessmenCreditCode":"2222",
                    "applyNo": "100002",
                    "invoiceTime": "2019-09-19",
                    "invoiceAmt":200000,
                    "settleImg": "https://bpohhr.gongsibao.com",
                    "type": 1
                }
                
            ],
            "times_tamp": 1568713248,
            "sign": "D4393F17C96CDA582C1EE5FF0053671E"
        }
    }
    请求参数说明：
        sign                      ：签名
        times_tamp                ：时间戳
        invoiceList               ：开票申请列表，最多不超过10个，不参与签名
        businessmenCreditCode     ：个体工商户统一社会信用代码
        applyNo                   ：开票申请编码（商户内唯一）
        invoiceTime               ：开票时间
        invoiceAmt                ：开票金额（分）
        settleImg                 ：结算单图片地址
        type                      ：开票类型 0普票 1专票
    返回值：
        {
            "status": 0,
            "msg": "success",
            "data": {
                "1111": {
                    "code": 1,
                    "msg": "success"
                },
                "2222": {
                    "code": 1,
                    "msg": "success"
                }
            },
            "requestid": "a39a364d83c14664b8e3399387fa847d"
        }
    返回值说明：
        data                        : 发票处理结果，Map格式，key为个体工商户统一社会信用代码
            "1"                     : 个体工商户统一社会信用代码
                "code"              : 该个体工商户试算状态 1成功 -1失败
                "msg"           : 试算结果提示，错误时返回错误信息    

11.cancelInvoice：发票申请撤回接口
    请求参数：
        {
            "action_process": "sjb",
            "action_type": "cancelInvoice",
            "action_body": {
                "applyNo": "100001"
            }
        }
    请求参数说明：
        sign                      ：签名
        times_tamp                ：时间戳
        applyNo                   ：开票申请编号
    返回值：
        {
            "status": 0,
            "msg": "success",
            "data": "success",
            "requestid": "090bde8c5bb74b9d8c6b97beabf39161"
        }

12.queryInvoice：发票查询接口
    请求参数：
        {
            "action_process": "sjb",
            "action_type": "queryInvoice",
            "action_body": {
                "applyNo": "100001"
            }
        }
    请求参数说明：
        sign                      ：签名
        times_tamp                ：时间戳
        applyNo                   ：开票申请编号
    返回值：
        {
            merchant_id   // 商户id 
            applyNo       // 发票申请编号
            status        // 发票状态 00开票申请 10已撤回 20审核驳回 30审核通过 40已开票 50已邮寄

            auditRemark   // 审核备注

            invoiceNo     // 发票编号
            invoiceTime   // 开票时间
            invoiceImg    // 发票照片
            payVoucher    // 支付凭证

            courierNo   // 快递单号
            courierImg  //  快递交接单图片

            taxNo       // 完税批号
            taxTime     // 完税时间
            taxVoucher  // 完税证明（图片地址）
        }
13.queryTaxInvoice：完税证明查询
    请求参数：
        {
            "action_process": "sjb",
            "action_type": "queryTaxInvoice",
            "action_body": {
                "applyNo": "100001"
            }
        }
    请求参数说明：
        sign                      ：签名
        times_tamp                ：时间戳
        applyNo                   ：开票申请编号
    返回值：
        {
            merchant_id   // 商户id 
            applyNo       // 发票申请编号
            complateTax   // 是否完税  0否 1是
            taxNo         // 完税批号
            taxTime       // 完税时间
            taxVoucher    // 完税证明（图片地址）
        }

14: queryCourierTrace：查询邮寄进度
请求参数：
    {
        "action_process": "sjb",
        "action_type": "queryTaxInvoice",
        "action_body": {
            "applyNo": "100001"
        }
    }
请求参数说明：
    sign                      ：签名
    times_tamp                ：时间戳
    applyNo                   ：开票申请编号
返回值：
    {
        merchant_id   // 商户id 
        applyNo       // 发票申请编号
        courierNo     // 快递单号
        courierStatus // 邮寄状态
        courierTime   // 时间
        desc          // 描述信息
    }


------------------------------------------------------------------------------------------------------------------------------------------   
------------------------------------------------------------------------------------------------------------------------------------------
通知回调商户接口：需要商户提供以下接收的回调地址，回调方式：POST
    1. 充值审核  
    2. 商户修改接口  
    3. 订单修改接口  
    4. 订单状态变更推送
    5. 发票状态变更推送
    6. 发票完税证明推送
1.充值审核
{
    merchant_id     // 商户id  
    outTradeNo     // 充值流水号,
    status         // 充值状态 1已认证 2审核失败
    remark         // 审核备注
}

4. 订单状态变更推送
{
    merchant_id,// 商户id                                                                                          
    status,     // 00待处理 05执照办理中 10已出执照 15刻章办理中 20已刻章 25银行开户中 30银行已开户 35税务报到中 40已税务报到 50已邮寄
    channelOrderNo,//  渠道订单号    

    // ----- 出执照推送数据 -----
    name ,//  个体工商户名称                                                                             
    creditCode,//  统一社会信用代码                                                                          
    businessPlace,//  经营场所                                                                                      
    businessScope,//  经营范围                                                                                      
    regDate,//  注册日期                                                                                      
    businessImg,//  执照照片                                                                                               
    orderNo,//  订单号                                                                                         
    legalName,//  法人姓名                                                                                      
    legalMobile,//  法人电话  
    
    // ----- 刻章推送数据 -----
    gongzhang,  //        公章                                                                                            
    caiwuzhang,  //        财务章                                                                                         
    businessImg,  //        执照照片                                                                                      
    fapiaozhang,  //        发票章                                                                                         
    hetongzhang,  //        合同章                                                                                         
    farenzhang  //        法人章    

    // ----- 开户推送数据 -----
    isBank,//  是否开户                                                                                      
    bankName,//  账户名称                                                                                      
    bankNo,//  账户号                                                                                         
    bank,//  开户行                                                                                         
    bankImg  //  账户信息   


    // ----- 税务报到推送数据 -----
    caImg,//  CA照片                                                                                      
    taxRegDay,//  税务登记日                                                                                      
    taxOrg//  税务机构名称 

    // ----- 邮寄推送数据 -----
    courierNo,  // 快递单号                                                                                       
    courierImg  // 快递交接单图片 

    // ----- 已完成推送数据 -----
    completeTime  // 快递交接单图片 
}    

5.发票状态变更推送
    {
        merchant_id  // 商户id 
        applyNo       // 发票申请编号
        status        // 发票状态 00开票申请 10已撤回 20审核驳回 30审核通过 40已开票 50已邮寄

        // ----- 发票审核数据字段 -----
        auditRemark   // 审核备注

        // ----- 发票开具数据字段 -----
        invoiceNo     // 发票编号
        invoiceTime   // 开票时间
        invoiceImg    // 发票照片
        payVoucher    // 支付凭证

        // ----- 发票邮件数据字段 -----
        courierNo   // 快递单号
        courierImg  //  快递交接单图片

    }
6.发票完税证明推送
    {
        merchant_id    // 商户id 
        applyNo       // 发票申请编号
        complateTax   // 是否完税  0否 1是
        taxNo         // 完税批号
        taxTime       // 完税时间
        taxVoucher    // 完税证明（图片地址）
    }
    <pre/>`;
    }
    classDesc() {
        return {
            groupName: "op",
            groupDesc: "元数据服务包",
            name: "ActionAPI",
            desc: "此类是对外提供接口服务",
            exam: "",
        };
    }
    methodDescs() {
        return [
            {
                methodDesc: `<pre>请求地址：http://sj.app.com:3002/api/op/action/springboard   
    请求时需要在请求头中增加app_id参数信息，app_id由平台提供给调用方
    方法中的签名只有action_body中的参数参与，按照参数的首字母进行ASCII码进行正序排列后进行签名，action_body中的参数为空或参数为list或为json的不参与签名
    签名字符串示例：times_tamp=1568713248&key=XXXX，key为平台提供的密钥，对字符串进行
    后进行大写转换
    方法中需要传递的action_type列表有： 
        queryMerchant：查询商户    
        addOrder：添加订单
        putOrder：修改订单
        queryOrder：订单查询
        putContract：个体工商户合同接收接口
        queryBusinessmen：个体工商户信息查询接口
<pre/>`,
                methodName: "springboard",
                paramdescs: [
                    {
                        paramDesc: "请求的行为，传递如：sjb",
                        paramName: "action_process",
                        paramType: "string",
                        defaultValue: null,
                    },
                    {
                        paramDesc: "业务操作类型，详情见方法中的描述",
                        paramName: "action_type",
                        paramType: "string",
                        defaultValue: null,
                    },
                    {
                        paramDesc: "业务操作类型的参数，action_body必须传递的参数有，times_tamp（时间戳，类型int）、sign(签名,类型string)，其余的为业务需要的参数",
                        paramName: "action_body",
                        paramType: "json",
                        defaultValue: null,
                    }
                ],
                rtnTypeDesc: `<pre>
                status: 返回状态,
                msg: 返回信息描述，验证有误则为错误提示,
                data: 返回数据信息,
                requestid: 返回的处理此次请求的凭证               
                status状态码如下：
                0     业务请求处理成功
                -1    请求参数验证失败
                1200  访问appid失效
                1300  签名验证失败
            <pre/>`,
                rtnType: `<pre>
                {
                    "status": 0,
                    "msg": "success",
                    "data": {},
                    "requestid": "8cbd498f9d1441b1812ecaa2653933f4"
                }
            <pre/>`
            }
        ];
    }
}
module.exports = ActionAPI;